@@ -1,6 +1,5 @@
 from PasswordCardGenerator import PasswordCard
 import PasswordCardGenerator.Web as Web
-import PasswordCardGenerator.GUI as GUI
 from random import choices, randint
 from os import path
 import argparse
@@ -113,7 +112,6 @@ parser.add_argument("-p", "--png", action="store_true", help="Saves the Password
 parser.add_argument("-s", "--seed", action="store", type=str or int, help="Set the seed")
 parser.add_argument("--pwd", action="store_true", help="Gets the Password for [keyword]")
 parser.add_argument("--web", action="store_true", help="Start the Web version")
-parser.add_argument("--gui", action="store_true", help="Start the GUI")
 
 # getting the args
 args = parser.parse_args()
@@ -121,9 +119,6 @@ args = parser.parse_args()
 if args.web:
     Web.run()
     exit(0)
-if args.gui:
-    GUI.app.run()
-    exit(0)
 
 # generating keyword if needed
 keyword, generated = '.'.join(args.keyword), False
